import{h as l,e as n}from"./reka-ui-CE6xzTAG.js";import{c}from"./index-CPxkwG0x.js";import{d as p,G as i,u as s,D as d,H as m,h as f,b as u}from"./lucide-6UWTdd2w.js";import{l as _}from"./vueuse-BmOENVLt.js";const P=p({__name:"DialogDescription",props:{asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]}},setup(e){const o=e,a=_(o,"class"),t=l(a);return(r,g)=>(u(),i(s(n),d({"data-slot":"dialog-description"},s(t),{class:s(c)("text-muted-foreground text-sm",o.class)}),{default:m(()=>[f(r.$slots,"default")]),_:3},16,["class"]))}});export{P as _};
