import{c as s}from"./index-CPxkwG0x.js";import{d as o,c as t,ae as n,u as c,h as d,b as l}from"./lucide-6UWTdd2w.js";const u=o({__name:"CardHeader",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(a){const r=a;return(e,i)=>(l(),t("div",{"data-slot":"card-header",class:n(c(s)("@container/card-header grid auto-rows-min grid-rows-[auto_auto] items-start gap-1.5 px-6 has-data-[slot=card-action]:grid-cols-[1fr_auto] [.border-b]:pb-6",r.class))},[d(e.$slots,"default")],2))}});export{u as _};
