import{B as i}from"./lucide-6UWTdd2w.js";var l={outline:{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor","stroke-width":2,"stroke-linecap":"round","stroke-linejoin":"round"},filled:{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"currentColor",stroke:"none"}};const w=(e,n,s,h)=>({color:r="currentColor",size:o=24,stroke:p=2,title:c,class:y,...u},{attrs:d,slots:a})=>{let t=[...h.map(g=>i(...g)),...a.default?[a.default()]:[]];return c&&(t=[i("title",c),...t]),i("svg",{...l[e],width:o,height:o,...d,class:["tabler-icon",`tabler-icon-${n}`],...e==="filled"?{fill:r}:{"stroke-width":p??l[e]["stroke-width"],stroke:r},...u},t)};class m{parentSync;id;promiseResolver=null;constructor(n){this.parentSync=n,this.id=Symbol()}setScrollingDuration(n){n>0?this.parentSync._componentDurations.set(this.id,n):this.unregister()}maxDuration(){return this.parentSync._componentDurations.size===0?0:Math.max(...this.parentSync._componentDurations.values())}sync(){return new Promise(n=>{this.promiseResolver=n,this.parentSync._pendingSync.push(n),this.parentSync._tryResolveWaiting()})}unregister(){if(this.promiseResolver){const n=this.parentSync._pendingSync.indexOf(this.promiseResolver);n>-1&&this.parentSync._pendingSync.splice(n,1),this.promiseResolver(),this.promiseResolver=null}this.parentSync._componentDurations.delete(this.id),this.parentSync._tryResolveWaiting()}}class _{_componentDurations;_pendingSync;constructor(){this._componentDurations=new Map,this._pendingSync=[]}_registerAnimation(){return new m(this)}_tryResolveWaiting(){if(this._pendingSync?.length===this._componentDurations.size){const n=this._pendingSync;this._pendingSync=[];for(const s of n)s()}}}export{_ as M,w as c};
