import{u as g,W as B,X as h,Y as w,Z as P,_ as T,h as x,$ as C}from"./reka-ui-CE6xzTAG.js";import{d as i,G as d,u as e,D as p,H as l,h as c,L as $,M as D,b as u,J as _}from"./lucide-6UWTdd2w.js";import{c as y}from"./index-CPxkwG0x.js";import{l as b}from"./vueuse-BmOENVLt.js";const k=i({__name:"Tooltip",props:{defaultOpen:{type:Boolean},open:{type:Boolean},delayDuration:{},disableHoverableContent:{type:Boolean},disableClosingTrigger:{type:Boolean},disabled:{type:Boolean},ignoreNonKeyboardFocus:{type:Boolean}},emits:["update:open"],setup(t,{emit:o}){const n=g(t,o);return(r,f)=>(u(),d(e(B),p({"data-slot":"tooltip"},e(n)),{default:l(m=>[c(r.$slots,"default",$(D(m)))]),_:3},16))}}),A=i({inheritAttrs:!1,__name:"TooltipContent",props:{forceMount:{type:Boolean},ariaLabel:{},asChild:{type:Boolean},as:{},side:{},sideOffset:{default:4},align:{},alignOffset:{},avoidCollisions:{type:Boolean},collisionBoundary:{},collisionPadding:{},arrowPadding:{},sticky:{},hideWhenDetached:{type:Boolean},positionStrategy:{},updatePositionStrategy:{},class:{type:[Boolean,null,String,Object,Array],default:void 0}},emits:["escapeKeyDown","pointerDownOutside"],setup(t,{emit:o}){const a=t,s=o,n=b(a,"class"),r=g(n,s);return(f,m)=>(u(),d(e(h),null,{default:l(()=>[_(e(w),p({"data-slot":"tooltip-content"},{...e(r),...f.$attrs},{class:e(y)("bg-foreground text-background animate-in fade-in-0 zoom-in-95 data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=closed]:zoom-out-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 z-50 w-fit rounded-md px-3 py-1.5 text-xs text-balance",a.class)}),{default:l(()=>[c(f.$slots,"default"),_(e(P),{class:"bg-foreground fill-foreground z-50 size-2.5 translate-y-[calc(-50%_-_2px)] rotate-45 rounded-[2px]"})]),_:3},16,["class"])]),_:3}))}}),L=i({__name:"TooltipTrigger",props:{reference:{},asChild:{type:Boolean},as:{}},setup(t){const o=t;return(a,s)=>(u(),d(e(T),p({"data-slot":"tooltip-trigger"},o),{default:l(()=>[c(a.$slots,"default")]),_:3},16))}}),M=i({__name:"DropdownMenuLabel",props:{asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]},inset:{type:Boolean}},setup(t){const o=t,a=b(o,"class","inset"),s=x(a);return(n,r)=>(u(),d(e(C),p({"data-slot":"dropdown-menu-label","data-inset":t.inset?"":void 0},e(s),{class:e(y)("px-2 py-1.5 text-sm font-medium data-[inset]:pl-8",o.class)}),{default:l(()=>[c(n.$slots,"default")]),_:3},16,["data-inset","class"]))}});export{k as _,L as a,A as b,M as c};
