import{M as e,f as o,a as s}from"./index-CPxkwG0x.js";import{bk as t}from"./lucide-6UWTdd2w.js";let a=null;function d(i=1e4){a&&clearTimeout(a),a=setTimeout(()=>{a=null,s.triggerGenreScan().catch(()=>{})},i)}const m={[e.TRACK]:"mdi-music-note",[e.ALBUM]:"mdi-album",[e.ARTIST]:"mdi-account-music",[e.PLAYLIST]:"mdi-playlist-music",[e.RADIO]:"mdi-radio",[e.AUDIOBOOK]:"mdi-book-music",[e.PODCAST]:"mdi-podcast",[e.GENRE]:o,[e.GENRE_ALIAS]:t,[e.PODCAST_EPISODE]:"mdi-podcast",[e.FOLDER]:"mdi-folder",[e.UNKNOWN]:"mdi-help-circle-outline"},n={genre_artist:"artists",genre_album:"albums",genre_track:"tracks",genre_playlist:"playlists",genre_radio:"radios",genre_podcast:"podcasts",genre_audiobook:"audiobooks"};export{n as f,m as g,d as s};
