import{c as s}from"./index-CPxkwG0x.js";import{d as o,c as t,ae as n,u as c,h as l,b as d}from"./lucide-6UWTdd2w.js";const u=o({__name:"Card",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(a){const e=a;return(r,p)=>(d(),t("div",{"data-slot":"card",class:n(c(s)("bg-card text-card-foreground flex flex-col gap-6 rounded-xl border py-6 shadow-sm",e.class))},[l(r.$slots,"default")],2))}});export{u as _};
